SystemOrganization addCategory: #'Seaside-Tests-Session'!

WAContextTest subclass: #WAInteractionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WAInteractionTest commentStamp: 'pmm 4/6/2008 15:22' prior: 0!
The purpose of WAInteractionTest is to provide a fully initialized WContext all the neccsary objects are are normally there in a Seaside application like request, response, dispatcher applicaion, session and so forth.!

!WAInteractionTest methodsFor: 'accessing' stamp: 'jf 1/21/2009 12:19'!
application
	^self requestContext application! !

!WAInteractionTest methodsFor: 'private' stamp: 'lr 1/21/2009 15:11'!
createHandlers
	| dispatcher application session |
	dispatcher := WADispatcher named: 'rails'.
	application := (WAApplication named: 'homepage')
		setParent: dispatcher;
		yourself.
	session := WASession new.

	^super createHandlers, (Array with: dispatcher with: application with: session)! !

!WAInteractionTest methodsFor: 'accessing' stamp: 'jf 1/21/2009 12:19'!
session
	^self requestContext session! !

!WAInteractionTest methodsFor: 'testing' stamp: 'pmm 4/6/2008 15:27'!
testContentType
	| contentType |
	self application preferenceAt: #mimeType put: 'application/xhtml+xml'.
	self application preferenceAt: #charSet put: 'iso-8859-1'.
	
	contentType := WAResponse new contentType.
	self assert: contentType main = 'application'.
	self assert: contentType sub = 'xhtml+xml'.
	self assert: contentType charset = 'iso-8859-1'! !

!WAInteractionTest methodsFor: 'testing' stamp: 'lr 1/21/2009 20:33'!
testDeleteNetscapeCookie
	| requestCookie responseCookies responseCookie |
	self application preferenceAt: #serverPath put: '/en/private_kunden/wealth_management'.
	requestCookie := WARequestCookie key: 'password' value: 'sex'.
	self requestContextWithUrl: '/' cookies: (Array with: requestCookie).
	self requestContext response deleteCookie: requestCookie.
	
	responseCookies := self requestContext response cookies.
	self assert: responseCookies size = 1.
	responseCookie := responseCookies anyOne.
	
	self assert: (responseCookie isKindOf: WACookie).
	self assert: responseCookie value = ''.
	self assert: responseCookie path = self application baseUrl pathString! !

!WAInteractionTest methodsFor: 'testing' stamp: 'lr 1/21/2009 20:34'!
testDeleteRfc2965Cookie
	| requestCookie responseCookies responseCookie |
	requestCookie := (WARequestCookie key: 'password' value: 'sex')
		path: '/en/private_kunden/wealth_management';
		version: 1;
		yourself.
	self requestContextWithUrl: '/' cookies: (Array with: requestCookie).
	self requestContext response deleteCookie: requestCookie.
	
	responseCookies := self requestContext response cookies.
	self assert: responseCookies size = 1.
	responseCookie := responseCookies anyOne.
	
	self assert: (responseCookie isKindOf: WACookie).
	self assert: responseCookie value = ''.
	self assert: responseCookie path = '/en/private_kunden/wealth_management'! !

!WAInteractionTest methodsFor: 'testing' stamp: 'jf 1/21/2009 12:20'!
testNewCookie
	| cookie |
	cookie := self requestContext newCookie.
	self assert: cookie path = self application baseUrl pathString.
	self assert: cookie ports isNil.
	self assert: cookie httpOnly.
	self deny: cookie secure.
	self assert: cookie domain isNil.
	
	self application preferenceAt: #serverPath put: '/en/private_kunden/wealth_management'.
	cookie := self requestContext newCookie.
	self assert: cookie path = '/en/private_kunden/wealth_management'.
	self assert: cookie ports isNil.
	self assert: cookie httpOnly.
	self deny: cookie secure.
	self assert: cookie domain isNil.
	
	self application preferenceAt: #serverPort put: 8080.
	self application preferenceAt: #serverProtocol put: 'https'.
	self application preferenceAt: #serverHostname put: 'www.lgt.com'.
	cookie := self requestContext newCookie.
	self assert: cookie path = '/en/private_kunden/wealth_management'.
	self deny: cookie ports isNil.
	self assert: cookie ports size = 1.
	self assert: cookie ports first = 8080.
	self assert: cookie httpOnly.
	self assert: cookie secure.
	self assert: cookie domain = 'www.lgt.com'! !

WACanvasBrushTest subclass: #WAResourceBaseUrlTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WAResourceBaseUrlTest methodsFor: 'private' stamp: 'jf 1/23/2009 03:32'!
assertRoot: aBlock gives: aString
	| html |
	html := WARenderCanvas builder
		fullDocument: true;
		rootBlock: aBlock;
		render: [ :canvas | ].
	self assert: html = ('<html><head><title></title>', aString, '</head><body><script type="text/javascript">/*<!![CDATA[*/function onLoad(){}/*]]>*/</script></body></html>')! !

!WAResourceBaseUrlTest methodsFor: 'private' stamp: 'lr 1/21/2009 21:33'!
createHandlers
	^ super createHandlers , (Array 
		with: (WAApplication new
			preferenceAt: #resourceBaseUrl put: self resourceBaseUrl;
			yourself)
		with: WASession new)! !

!WAResourceBaseUrlTest methodsFor: 'private' stamp: 'pmm 1/7/2008 19:09'!
resourceBaseUrl
	^'https:/www.seaside.st/resources/'! !

!WAResourceBaseUrlTest methodsFor: 'testing' stamp: 'pmm 1/7/2008 19:14'!
testAbsoluteFtpUrl
	self
		assert: [ :html | html anchor resourceUrl: 'ftp://www.google.com/track.js' ]
		gives: '<a href="ftp://www.google.com/track.js"></a>'! !

!WAResourceBaseUrlTest methodsFor: 'testing' stamp: 'pmm 1/7/2008 19:12'!
testAbsoluteHttpUrl
	self
		assert: [ :html | html anchor resourceUrl: 'http://www.google.com/track.js' ]
		gives: '<a href="http://www.google.com/track.js"></a>'! !

!WAResourceBaseUrlTest methodsFor: 'testing' stamp: 'pmm 1/7/2008 19:13'!
testAbsoluteHttpsUrl
	self
		assert: [ :html | html anchor resourceUrl: 'https://www.google.com/track.js' ]
		gives: '<a href="https://www.google.com/track.js"></a>'! !

!WAResourceBaseUrlTest methodsFor: 'testing' stamp: 'pmm 1/7/2008 19:11'!
testFileNameWithHttp
	self
		assert: [ :html | html image resourceUrl: 'http.gif' ]
		gives: '<img alt="" src="https:/www.seaside.st/resources/http.gif"/>'! !

!WAResourceBaseUrlTest methodsFor: 'testing' stamp: 'pmm 1/7/2008 19:11'!
testImageTag
	self
		assert: [ :html | html image resourceUrl: 'logo.jpeg' ]
		gives: '<img alt="" src="https:/www.seaside.st/resources/logo.jpeg"/>'! !

!WAResourceBaseUrlTest methodsFor: 'testing' stamp: 'pmm 1/7/2008 19:21'!
testRootScript
	self
		assertRoot: [ :html | html javascript resourceUrl: 'main.js' ]
		gives: '<script type="text/javascript" src="https:/www.seaside.st/resources/main.js"></script>'! !

!WAResourceBaseUrlTest methodsFor: 'testing' stamp: 'pmm 2/14/2008 21:17'!
testScriptTag
	self
		assert: [ :html | html script resourceUrl: 'track.js' ]
		gives: '<script src="https:/www.seaside.st/resources/track.js" type="text/javascript">/*<!![CDATA[*//*]]>*/</script>'! !

!WAResourceBaseUrlTest methodsFor: 'testing' stamp: 'pmm 1/7/2008 19:18'!
testSylesheet
	self
		assertRoot: [ :html | html stylesheet resourceUrl: 'main.css' ]
		gives: '<link rel="stylesheet" type="text/css" href="https:/www.seaside.st/resources/main.css"/>'! !

!WAPackage class methodsFor: '*seaside-tests-session' stamp: 'lr 10/23/2008 21:36'!
seasideTestsSession
	^ self new
		name: 'Seaside-Tests-Session';
		description: 'Unit tests for the package Seaside-Session.';
		addDependency: 'Seaside-Session';
		addDependency: 'Seaside-Tests-Core';
		yourself! !

WARegistryTest subclass: #WAApplicationTest
	instanceVariableNames: 'request'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WAApplicationTest methodsFor: 'running' stamp: 'jf 10/7/2008 01:36'!
newEntryPoint
	^ WAApplication named: 'app'! !

!WAApplicationTest methodsFor: 'running' stamp: 'pmm 11/30/2008 16:02'!
requestWithMethod: aString
	^WARequest
		method: aString
		url: '/oneo'
		headers: Dictionary new
		fields: Dictionary new
		cookies: Array new
		remoteAddress: '127.0.0.1'! !

!WAApplicationTest methodsFor: 'running' stamp: 'jf 10/7/2008 00:48'!
setUp
	super setUp.
	request := WARequest new! !

!WAApplicationTest methodsFor: 'testing' stamp: 'jf 10/7/2008 00:45'!
testEmpty
	self assert: (handler sessionCookieFor: request) isNil! !

!WAApplicationTest methodsFor: 'testing' stamp: 'lr 1/21/2009 20:25'!
testNotImplemented
	| context |
	#('OPTIONS' 'HEAD' 'PUT' 'DELETE' 'TRACE' 'CONNECT') do: [ :each |
		request := self requestWithMethod: each.
		context := WARequestContext request: request response: WABufferedResponse new.
		[ handler handleFiltered: context ]
			on: WAResponseNotification
			do: [ :notification | ].
		self assert: context response status = 501 ].
	
	#('GET' 'POST') do: [ :each |
		request := self requestWithMethod: each.
		context := WARequestContext request: request response: WABufferedResponse new.
		[ handler handleFiltered: context ]
			on: WAResponseNotification
			do: [ :notification | ].
		self assert: context response status ~= 501 ]! !

!WAApplicationTest methodsFor: 'testing' stamp: 'jf 10/7/2008 00:47'!
testOneOfMany
	| cookie1 cookie2 cookie3 cookie4 actual |
	cookie1 := WARequestCookie key: '_s' value: '1234'.
	cookie2 := (WARequestCookie key: '_s' value: '1234')
		path: '/';
		yourself.
	cookie3 := (WARequestCookie key: '_s' value: '1234')
		path: '/1/2';
		yourself.
	cookie4 := (WARequestCookie key: '_s' value: '1234')
		path: '/1/2/3';
		yourself.
	request := WARequest
		method: 'GET'
		url: '/1/2'
		headers: Dictionary new
		fields: Dictionary new
		cookies: (Array
			with: cookie1
			with: cookie2
			with: cookie3
			with: cookie4)
		remoteAddress: '127.0.0.1'.
	actual := handler sessionCookieFor: request.
	self assert: actual == cookie3! !

!WAApplicationTest methodsFor: 'testing' stamp: 'jf 10/7/2008 00:46'!
testOneOfManySlashInCookie
	| cookie1 cookie2 cookie3 cookie4 actual |
	cookie1 := WARequestCookie key: '_s' value: '1234'.
	cookie2 := (WARequestCookie key: '_s' value: '1234')
		path: '/';
		yourself.
	cookie3 := (WARequestCookie key: '_s' value: '1234')
		path: '/1/2/';
		yourself.
	cookie4 := (WARequestCookie key: '_s' value: '1234')
		path: '/1/2/3/';
		yourself.
	request := WARequest
		method: 'GET'
		url: '/1/2'
		headers: Dictionary new
		fields: Dictionary new
		cookies: (Array
			with: cookie1
			with: cookie2
			with: cookie3
			with: cookie4)
		remoteAddress: '127.0.0.1'.
	actual := handler sessionCookieFor: request.
	self assert: actual == cookie3! !

!WAApplicationTest methodsFor: 'testing' stamp: 'jf 10/7/2008 00:46'!
testOneOfManySlashInUrl
	| cookie1 cookie2 cookie3 cookie4 actual |
	cookie1 := WARequestCookie key: '_s' value: '1234'.
	cookie2 := (WARequestCookie key: '_s' value: '1234')
		path: '/';
		yourself.
	cookie3 := (WARequestCookie key: '_s' value: '1234')
		path: '/1/2';
		yourself.
	cookie4 := (WARequestCookie key: '_s' value: '1234')
		path: '/1/2/3';
		yourself.
	request := WARequest
		method: 'GET'
		url: '/1/2/'
		headers: Dictionary new
		fields: Dictionary new
		cookies: (Array
			with: cookie1
			with: cookie2
			with: cookie3
			with: cookie4)
		remoteAddress: '127.0.0.1'.
	actual := handler sessionCookieFor: request.
	self assert: actual == cookie3! !

!WAApplicationTest methodsFor: 'testing' stamp: 'jf 10/7/2008 00:46'!
testOnlyOne
	| cookie1 cookie2 |
	cookie1 := WARequestCookie key: '_s' value: '1234'.
	request := WARequest
		method: 'GET'
		url: '/'
		headers: Dictionary new
		fields: Dictionary new
		cookies: (Array with: cookie1)
		remoteAddress: '127.0.0.1'.
	cookie2 := handler sessionCookieFor: request.
	self assert: cookie1 == cookie2! !

!WAApplicationTest methodsFor: 'testing' stamp: 'jf 10/7/2008 00:46'!
testWrongKey
	| cookie |
	cookie := WARequestCookie key: '_k' value: '1234'.
	request := WARequest
		method: 'GET'
		url: '/'
		headers: Dictionary new
		fields: Dictionary new
		cookies: (Array with: cookie)
		remoteAddress: '127.0.0.1'.
	self assert: (handler sessionCookieFor: request) isNil! !

!WAApplicationTest methodsFor: 'testing' stamp: 'jf 10/7/2008 00:46'!
testWrongPrefix
	| cookie1 cookie2 actual |
	cookie1 := WARequestCookie key: '_s' value: '1234'.
	cookie2 := (WARequestCookie key: '_s' value: '1234')
		path: '/one';
		yourself.

	request := WARequest
		method: 'GET'
		url: '/oneo'
		headers: Dictionary new
		fields: Dictionary new
		cookies: (Array
			with: cookie1
			with: cookie2)
		remoteAddress: '127.0.0.1'.
	actual := handler sessionCookieFor: request.
	self assert: actual == cookie1! !

TestCase subclass: #WACurrentSessionTest
	instanceVariableNames: 'savedContinuation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WACurrentSessionTest commentStamp: 'pmm 3/29/2008 12:34' prior: 0!
A WACurrentSessionTest is to make sure

WACurrentSession value

works as in Seaside 2.9 as it did in earlier versions.
!

!WACurrentSessionTest methodsFor: 'running' stamp: 'lr 4/9/2008 09:38'!
setUp
	super setUp.
	WACurrentRequestContext reset! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'lr 1/21/2009 20:16'!
testBalancedContextContinuations
	"Cause the ensure blocks in WAContext to fire - use balanced nesting and things work fine"
	| x session alternateSession tertiarySession quatenarySession context |
	session := WASession new.
	alternateSession := WASession new.
	tertiarySession := WASession new.
	quatenarySession := WASession new.
	context := WARequestContext request: nil response: nil.
	WACurrentRequestContext 
		use: context
		during: 
			[ WACurrentRequestContext value 
				push: tertiarySession
				while: 
					[ self assert: WACurrentRequestContext value session == tertiarySession.
					WACurrentRequestContext value 
						push: session
						while: 
							[ x := WAContinuation currentDo: 
								[ :cc | 
								savedContinuation := cc.
								0 ].
							x == 0 
								ifTrue: [ self assert: WACurrentRequestContext value session == session ]
								ifFalse: 
									[ self assert: x = 1.
									self assert: WACurrentRequestContext value session == quatenarySession ] ].
					x == 0 ifTrue: 
						[ self assert: WACurrentRequestContext value session == tertiarySession ].
					x == 1 ifTrue: 
						[ self assert: WACurrentRequestContext value session == alternateSession ] ] ].
	x ~~ 1 ifTrue: 
		[ WACurrentRequestContext 
			use: context
			during: 
				[ WACurrentRequestContext value 
					push: alternateSession
					while: 
						[ WACurrentRequestContext value 
							push: quatenarySession
							while: [ savedContinuation value: 1 ] ] ] ]! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'lr 1/21/2009 20:16'!
testContinuationInheritance
	"Verify that continuation inherits it's context from parent process"
	| x session alternateSession context |
	session := WASession new.
	alternateSession := WASession new.
	context := WARequestContext request: nil response: nil.
	WACurrentRequestContext 
		use: context
		during: 
			[ WACurrentRequestContext value 
				push: session
				while: 
					[ x := WAContinuation currentDo: 
						[ :cc | 
						savedContinuation := cc.
						0 ].
					x == 0 
						ifTrue: [ self assert: WACurrentRequestContext value session == session ]
						ifFalse: 
							[ self assert: x = 1.
							self assert: WACurrentRequestContext value session == alternateSession ] ] ].
	x ~~ 1 ifTrue: 
		[ WACurrentRequestContext 
			use: context
			during: 
				[ WACurrentRequestContext value 
					push: alternateSession
					while: [ savedContinuation value: 1 ] ] ]! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'lr 1/21/2009 20:16'!
testContinuations
	"verify that process variable not copied by continuation."
	| x session context |
	session := WASession new.
	context := WARequestContext request: nil response: nil.
	WACurrentRequestContext 
		use: context
		during: 
			[ WACurrentRequestContext value 
				push: session
				while: 
					[ x := WAContinuation currentDo: 
						[ :cc | 
						savedContinuation := cc.
						0 ].
					x == 0 ifTrue: 
						[ self assert: WACurrentSession value == session.
						"invoke continuation for the first time - reuse process variables"
						savedContinuation value: 1 ].
					x == 1 ifTrue: 
						[ self assert: WACurrentSession value = session.
						WACurrentRequestContext reset.
						"invoke continuation for the second time - process variables reset"
						savedContinuation value: 2 ].
					"no value for WACurrentSession after continuation invoked for second time"
					self assert: x = 2.
					self assert: WACurrentSession value isNil ] ]! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'lr 1/21/2009 20:17'!
testSimpleContinuation
	"verify that continuation reuses the process variable from the current process."
	| x continuation session context |
	session := WASession new.
	context := WARequestContext request: nil response: nil.
	WACurrentRequestContext 
		use: context
		during: 
			[ WACurrentRequestContext value 
				push: session
				while: 
					[ x := WAContinuation currentDo: 
						[ :cc | 
						continuation := cc.
						false ].
					self assert: WACurrentSession value = session.
					x ifFalse: [ continuation value: true ].
					self assert: x ] ]! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'lr 1/21/2009 20:17'!
testWithValue
	| session context |
	session := WASession new.
	context := WARequestContext request: nil response: nil.
	WACurrentRequestContext 
		use: context
		during: 
			[ WACurrentRequestContext value 
				push: session
				while: [ self assert: WACurrentSession value = session ] ]! !

!WACurrentSessionTest methodsFor: 'testing' stamp: 'pmm 3/29/2008 12:35'!
testWithoutValue
	self assert: WACurrentSession value isNil! !
